package App::WHOGrowthReferenceUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-03-15'; # DATE
our $DIST = 'App-WHOGrowthReferenceUtils'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Utilities related to WHO growth reference

__END__

=pod

=encoding UTF-8

=head1 NAME

App::WHOGrowthReferenceUtils - Utilities related to WHO growth reference

=head1 VERSION

This document describes version 0.004 of App::WHOGrowthReferenceUtils (from Perl distribution App-WHOGrowthReferenceUtils), released on 2021-03-15.

=head1 DESCRIPTION

This distributions provides the following command-line utilities:

=over

=item * L<get-who-growth-reference>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-WHOGrowthReferenceUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-WHOGrowthReferenceUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-WHOGrowthReferenceUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<WHO::GrowthReference::Table>

These distributions also have some CLIs: L<WHO::GrowthReference::GenTable>,
L<WHO::GrowthReference::GenChart>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
